@@ -1,8 +1,8 @@
       subroutine avas(p,n,x,y,w,l,delrsq,tx,ty,rsq,ierr,m,z,yspan,iter,
      1 iters)
-      integer p,pp1,pp2,m(n,1),l(1)
+      integer p,pp1,pp2,m(n,*),l(*)
       double precision y(n),x(n,p),w(n),ty(n),tx(n,p),z(n,17),ct(10)
-      double precision iters(100,2), delrsq, rsq, yspan
+      double precision iters(100,2), delrsq, rsq, yspan, rss
       common /parms/ itape,maxit,nterm,span,alpha
       double precision sm,sv,sw,svx
       ierr = 0
@@ -80,6 +80,7 @@
       z(j,4)=z(k,2)
       z(j,5)=w(k)
 23031 continue
+c NB: rss is double precision, dof is not.
       call rlsmo(z(1,10),z(1,4),z(1,5),yspan,dof,n,z(1,6),rss,z(1,7))
       do 23033 j=1,n
       k=m(j,pp2)
@@ -141,7 +142,7 @@
       return
       end
       subroutine calcmu(n,p,l,z,tx)
-      integer p, l(1)
+      integer p, l(*)
       double precision z(n,17),tx(n,p)
       do 23055 j=1,n
       z(j,10)=0
@@ -154,7 +155,7 @@
       return
       end
       subroutine bakfit(iter,delrsq,rsq,sw,l,z,m,x,ty,tx,w,n,p,np)
-      integer l(1),m(n,1),p
+      integer l(*),m(n,*),p
       double precision z(n,17),ty(n),tx(n,p),x(n,p),w(n)
       double precision sm,sv,sw, delrsq, rsq
       common /parms/ itape,maxit,nterm,span,alpha
@@ -210,7 +211,7 @@
       return
       end
       subroutine ctsub(n,u,v,y,ty)
-      double precision u(1),v(1),y(1),ty(1)
+      double precision u(*),v(*),y(*),ty(*)
       i=1
 23088 if(.not.(i.le.n))goto 23090
       if(.not.(y(i).le.u(1)))goto 23091
@@ -432,7 +433,7 @@ c
 c     this is a modification of cacm algorithm #347 by r. c. singleton,
 c     which is a modified hoare quicksort.
 c
-      dimension a(jj),v(1)
+      dimension a(jj),v(*)
       integer iu(20),il(20)
       integer t,tt
       integer a
